@@ -63,7 +63,7 @@
     (set! offsetx (number->string (+ (string->number offsetx) (string->number oldx))))
     (set! offsety (number->string (+ (string->number offsety) (string->number oldy))))
     (d-DirectivePut-standalone-prefix tag (string-append " <>-\\tweak #'extra-offset #'(" offsetx " . " offsety ")"))
-    (if (pair? data)
+    (if (list? data)
         (begin
             (set! data (assq-set! data 'x-offset offsetx))
             (set! data (assq-set! data 'y-offset offsety))
@@ -127,7 +127,7 @@
             (set! data (assq-set! data 'x-offset offsetx))
             (set! data (assq-set! data 'y-offset offsety))
             (put-data-command tag (format #f "'~s" data))))
-    (set! start (string-append "\\once \\override " context what " #'" property " = #'("))
+    (set! start (string-append "\\once \\override " context what "." property " = #'("))
     (set! end ")")
     (put-command tag (string-append start offsetx " . " offsety end)) 
     (if override
@@ -177,7 +177,7 @@
             (override-command override))))
 
 ; ChangeOffset
-;; e.g.  (define prefixstring      "\\once \\override Fingering  #'extra-offset = #'(")
+;; e.g.  (define prefixstring      "\\once \\override Fingering.extra-offset = #'(")
 ;; (define postfix ")")
 ;; (ChangeOffset "something first hello 12.6 . 13.8 etc and something after"  "hello " " etc" (cons "14.2" "55.5") )
 (define (ChangeOffset oldstr prefixstring postfixstring offset)
@@ -237,7 +237,7 @@
     (if sa-tag      
         (let ()
                 (if grob
-                    (cond ((or (equal? grob "RehearsalMark") (equal? grob "BreathingSign")   (equal? grob "MetronomeMark")    )
+                    (cond ((or (equal? grob "RehearsalMark")(equal? grob "TextMark") (equal? grob "TextEndMark")(equal? grob "BreathingSign")   (equal? grob "MetronomeMark")    )
                             (ExtraOffset sa-tag grob "standalone" "Score." (cons offsetx offsety)))
                         (#t
                             (TweakRelativeOffset sa-tag offsetx offsety)))
@@ -253,7 +253,7 @@
             (if (Rest?)
                 (ExtraOffset "RestOffset" "Rest" "chord" "Voice." (cons offsetx offsety) DENEMO_OVERRIDE_AFFIX)
                 (if (equal? grob "BassFigure")
-          (d-AdjustBassFigureHeight offsety)))))
+          (d-AdjustBassFigureHeight (cons "FBHeight1" offsety))))))
     (d-SetSaved #f))
 ;;;;;;;;;;;
 (define (SetSlur control-points)
@@ -266,8 +266,7 @@
     (define x4 (number->string (car (list-ref control-points 3))))
     (define y4 (number->string (cdr (list-ref control-points 3))))
     (d-DirectivePut-chord-prefix "Slur"             
-                    (string-append "\\once \\override Slur
-      #'control-points = #'((" x1 " . " y1 ") (" x2 " . " y2 ") (" x3 " . " y3 ") (" x4 " . " y4 ")) "))
+                    (string-append "\\once \\override Slur.control-points = #'((" x1 " . " y1 ") (" x2 " . " y2 ") (" x3 " . " y3 ") (" x4 " . " y4 ")) "))
   (d-DirectivePut-chord-display "Slur" "(")    
   (d-DirectivePut-chord-override "Slur" DENEMO_OVERRIDE_AFFIX)    
 )
@@ -282,8 +281,7 @@
     (define x4 (number->string (car (list-ref control-points 3))))
     (define y4 (number->string (cdr (list-ref control-points 0))))
     (d-DirectivePut-chord-prefix "Tie"             
-                    (string-append "\\once \\override Tie
-      #'control-points = #'((" x1 " . " y1 ") (" x2 " . " y2 ") (" x3 " . " y3 ") (" x4 " . " y4 ")) "))
+                    (string-append "\\once \\override Tie.control-points = #'((" x1 " . " y1 ") (" x2 " . " y2 ") (" x3 " . " y3 ") (" x4 " . " y4 ")) "))
   (d-DirectivePut-chord-display "Tie" "~")    
   (d-DirectivePut-chord-override "Tie" DENEMO_OVERRIDE_AFFIX)    
 )
@@ -334,7 +332,7 @@ simply click on four points: the start of the curve, two points outside along it
                   (ShapeTweakWarning)))
               
             (begin
-                        (d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest (Positioning will be done with respect to this height)"))
+                        (d-InfoDialog (_"First click on the red dot on center line of the staff aligning with the slur start note\n(Positioning will be done with respect to this height)"))
                         (if (d-GetReferencePoint)
                             (begin      
                                 (if (and (get-control-point 1)
@@ -369,7 +367,7 @@ simply click on four points: the start of the curve, two points outside along it
                   (ShapeTweakWarning)))
       
                     (begin
-                        (d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest (Positioning will be done with respect to this height)"))
+                        (d-InfoDialog (_"First click on the red dot on center line of the staff aligning with the tie start note\n(Positioning will be done with respect to this height)"))
                         (if (d-GetReferencePoint)
                             (begin      
                                 (if (and (get-control-point 1)
@@ -418,7 +416,7 @@ simply click on four points: the start of the curve, two points outside along it
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 (define EditTarget::WarningGiven #f)
 (define (EditTarget)
-    (let ((target (d-GetTargetInfo)) (target-type #f)(grob #f)(tag #f)) 
+    (let ((target (d-GetTargetInfo)) (target-type #f)(grob #f)(tag #f)) ;; target is a list (type grob tag)
     (define ta-tag "TextAnnotation")
 
     (define (do-offset)
@@ -438,7 +436,7 @@ simply click on four points: the start of the curve, two points outside along it
 You can use the right click menu to turn these on before invoking this command. However, since this marking code is only working well for single staffs, you can go ahead without.
 To do this dismiss this dialog and guess at where the red spot is on the object."))))
 
-        (d-InfoDialog (_"First click on the center line of the staff aligning with notehead/rest\n(Positioning will be done with respect to this height)"))
+        (d-InfoDialog (_"First click on the red dot on center line of the staff aligning with start note/rest\n(Positioning will be done with respect to this height)"))
         (d-GetReferencePoint)
         (d-InfoDialog (_"Now click on the position desired for the object"))
         (set! offset (d-GetOffset))
@@ -446,6 +444,20 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
           (begin
             (d-InfoDialog (_ "Re-positioned"))
             (TweakOffset grob tag (number->string (car offset)) (number->string (cdr offset)))))))
+    (define (do-absolute-offset)
+        (let ((offset #f))
+			;(d-InfoDialog (_"Click on the position desired for the object"))
+			(set! offset (d-GetOffset))
+			(if offset
+			  (let ((data (d-DirectiveGet-chord-prefix tag)))
+				;(d-InfoDialog (_ "Re-positioned"))
+				(if (not data)
+					(set! data  (cons 0  0))
+					(set! data  (eval-string (substring data 21))))
+				(set! data (cons (+ (car data) (car offset)) (+ (cdr data) (cdr offset)))) 		
+				(d-DirectivePut-chord-override tag (logior (d-DirectiveGet-chord-override tag) DENEMO_ALTAFFIX_OVERRIDE))
+				(d-DirectivePut-chord-prefix tag (string-append 
+					"\\tweak extra-offset #'" (format #f "~s " data)))))))  
                             
     (define (do-direction)
         (let ((direction #f)
@@ -457,9 +469,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (if (defined? (string->symbol (string-append "d-" tag)))
                         (eval-string (string-append "(d-" tag " (list (cons 'direction \"" choice "\")))"))
                         (eval-string (string-append "(d-ToggleCustomOrnament (list \"" tag "\" (cons 'direction \"" choice "\")))")))))))
-                                    
-                                    
-    
+
   (define (do-padding)
         (let ((padding (d-GetUserInput (_ "Padding") (_ "Give amount of padding required around this item (in staff spaces)") "0.5")))
         (if padding
@@ -467,10 +477,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (if (defined? (string->symbol (string-append "d-" tag)))
                                 (eval-string (string-append "(d-" tag " (list (cons 'padding \"" padding "\")))"))
                                 (eval-string (string-append "(d-ToggleCustomOrnament (list \"" tag "\" (cons 'padding \"" padding "\")))")))))))
-                                
-                                
-                            
-                            
+               
     (define (alter-text)
                 (d-TextAnnotation 'edit))
     (define (alter-font-size)
@@ -501,27 +508,33 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                 (begin
                                     (set! menu (cons  (cons "Set Font Size"  alter-font-size)  menu))
                                     (set! menu (cons  (cons "Alter Text"  alter-text)  menu))))
-                         
+                          (set! menu   (cons (cons (_ "Play From Here") d-DenemoPlayCursorToEnd) menu))        
                           (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
                           (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
-                         
-                          (set! choice (d-PopupMenu menu))
+                          
+                          (set! choice (d-PopupMenu (reverse menu)))
                           (if choice
                                 (choice)
                                 (disp "cancelled")))))
                                 
                     ((equal? target-type "Chord")
                             (let ((menu ""))
-                                (set! menu (list  (cons (_ "Up/Down") do-direction) (cons (_ "Padding") do-padding) (cons (_ "Offset Position") do-center-relative-offset)))   
+                                (set! menu (list  (cons (_ "Up/Down") do-direction) (cons (_ "Padding") do-padding)))
                                 ;;; FIXME the value is relative to the centre line of the staff, this gets relative to the tr sign.
                                 ;;;need to use d-GetNewTarget to find the notehead position, then use its mid_c_offset to get the centre line value
-                                ;;; beaming does this
-                                                   
+                                ;;; beaming does not come here, it is on Note target-type this 
+                                ;;;dragging rests is target = (CHORD, #f, #f) comes here
+                                ;; ornaments come here target =  (Chord #f ToggleMordent) for example
+                                
+                                (set! menu (cons (cons (_ "Offset Position") (if tag do-absolute-offset do-offset)) menu))
+                                (set! menu   (cons (cons (_ "Play From Here") d-DenemoPlayCursorToEnd) menu))    
+                                    
+                                      
                                 (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
                                 (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
-
+                                 
                                 
-                                (set! choice (d-PopupMenu menu))
+                                (set! choice (d-PopupMenu (reverse menu)))
                                 (if choice
                                         (choice)
                                         (disp "cancelled"))))
@@ -586,11 +599,11 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                                             (if (d-Directive-chord? "Tie")                                      
                                                 (set! menu (cons (cons RestoreTiePrompt 
                                                                                                     remove-tie-shaping) menu )))))                                                             
-                                                             
+                                    (set! menu   (cons (cons (_ "Play From Here") d-DenemoPlayCursorToEnd) menu))                              
                                     (set! menu (cons (cons (_ "Object Editor") d-EditCursorObject) menu))
                                     (set! menu (cons (cons (_ "Object Inspector") d-DisplayCurrentObject) menu))
-                                                                
-                                    (set! choice (d-PopupMenu menu))
+                                                            
+                                    (set! choice (d-PopupMenu (reverse menu)))
                                     (if choice
                                         (choice)
                                         (disp "cancelled"))))))))))  ;EditTarget end        
@@ -613,10 +626,10 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (set! choice (cond  ((equal? choice (_ "Up")) "^")
                                                             ((equal? choice (_ "Down")) "_")
                                                             ((equal? choice (_ "Auto")) "-")))
-                    (d-DirectivePut-chord-postfix tag (string-append  (string-append (if (d-GetNonprinting) "<>" "") choice " " lilypond " ")))
+                    (d-DirectivePut-chord-postfix tag (string-append  (string-append (if (and (AtRest?) (d-GetNonprinting)) "<>" "") choice " " lilypond " ")))
                     (d-SetSaved #f)))))
     (if (and (d-Directive-chord? tag) (equal? params "edit"))
-        (case (GetEditOption)
+        (case (GetEditOption (string-append (_ "Edit Directive tagged ") tag))
             ((edit) (direction-edit))
             ((cancel) #f)
             ((advanced) (d-DirectiveTextEdit-chord tag))
@@ -627,15 +640,16 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
                     (if (and (d-Directive-chord? tag) (list? params))
                                     (begin
                                         (d-SetSaved #f)
-                                         (if (d-GetNonprinting)
+                                         (if (and (AtRest?) (d-GetNonprinting))
                                             (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 0 1))
                                             (set! current-direction (substring (string-trim (d-DirectiveGet-chord-postfix tag)) 3 4))) ;;;FIXME use scheme data field to store this, <>- etc
                                             
                                             
-                                        (d-DirectivePut-chord-postfix tag (string-append (if (d-GetNonprinting) "<>" "") (string-join (map-in-order set-option params))  lilypond " ")))
+                                        (d-DirectivePut-chord-postfix tag (string-append (if (and (AtRest?) (d-GetNonprinting)) "<>" "") (string-join (map-in-order set-option params))  lilypond " ")))
                                     (d-WarningDialog "Cannot complete operation - cursor moved or bad parameter list")))
             (begin  ;;;no parameters, toggle annotation off/on
-                    (ToggleChordDirective tag graphic (string-append  (if (d-GetNonprinting) "<>" "")  "-" lilypond) DENEMO_OVERRIDE_ABOVE display)))))
+                    (ToggleChordDirective tag graphic (string-append  (if (and (AtRest?) (d-GetNonprinting)) "<>" "")  "-" lilypond) DENEMO_OVERRIDE_ABOVE display))))
+    (d-RefreshDisplay))
                                             
 (define* (ChordOrnament tag lilypond params graphic #:optional display)
        (ChordAnnotation tag lilypond params graphic display))  
@@ -651,16 +665,16 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
 (define (SetSlurPositions near far)
     (d-DirectivePut-chord-override "Slur" DENEMO_OVERRIDE_AFFIX)
   (d-DirectivePut-chord-prefix "Slur" (string-append 
-    "\\once \\override Slur #'direction = #" (if (or (> (string->number near) 0) (> (string->number far) 0)) "1" "-1") " "
-  "\\once \\override Slur  #'positions = #'(" near " . " far ")"))
+    "\\once \\override Slur.direction = #" (if (or (> (string->number near) 0) (> (string->number far) 0)) "1" "-1") " "
+  "\\once \\override Slur.positions = #'(" near " . " far ")"))
   (d-SetSaved #f))
   
  ; SetTiePositions
 (define (SetTiePositions near far)
     (d-DirectivePut-chord-override "Tie" DENEMO_OVERRIDE_AFFIX)
   (d-DirectivePut-chord-prefix "Tie" (string-append 
-    "\\once \\override Tie #'direction = #" (if (or (> (string->number near) 0) (> (string->number far) 0)) "1" "-1") " "
-  "\\once \\override Tie  #'positions = #'(" near " . " far ")"))
+    "\\once \\override Tie.direction = #" (if (or (> (string->number near) 0) (> (string->number far) 0)) "1" "-1") " "
+  "\\once \\override Tie.positions = #'(" near " . " far ")"))
   (d-SetSaved #f))
    
 ;;currently SetBeamPositions is just testing for offset with respect to 0, in fact it is the offset from the center staff line
@@ -670,7 +684,7 @@ To do this dismiss this dialog and guess at where the red spot is on the object.
     (d-DirectivePut-chord-override "Beam" DENEMO_OVERRIDE_AFFIX)
   (d-DirectivePut-chord-prefix "Beam" (string-append 
          (if (or (> (string->number near) 0) (> (string->number far) 0)) "\\stemUp" "\\stemDown") " "
-            "\\once \\override Beam  #'positions = #'(" near " . " far ")"))
+            "\\once \\override Beam.positions = #'(" near " . " far ")"))
   (d-SetSaved #f))
 
   
