@@ -1,3 +1,3 @@
 (AttachDirective "layout" "postfix" "MovementNoteheads" "\t\\context {
 \t\\Score		   
-\t\\override NoteHead  #'style = #'neomensural }\n")
\ No newline at end of file
+\t\\override NoteHead.style = #'neomensural }\n")
