@@ -1,7 +1,7 @@
-;;;PartCombine
-(let ((tag "PartCombine"))
+;;;PartCombine (no toggle when passed a parameter)
+(let ((tag "PartCombine")(name PartCombine::params))
 	(define (install-combine)
-		(if (d-Directive-voice? tag)
+		(if (and (d-Directive-voice? tag) (not name))
 			(begin
 				(d-DirectiveDelete-voice tag)
 				(d-MoveToVoiceDown)
@@ -9,14 +9,19 @@
 				(d-InfoDialog (_ "Parts are now uncombined")))
 			(begin
 				(d-DirectivePut-voice-prefix tag " \\set Staff.soloText = #\"\"
-  \\set Staff.soloIIText = #\"\"
-  \\set Staff.aDueText = #\"\" \\partcombine { ")
+                                                  \\set Staff.soloIIText = #\"\"
+                                                  \\set Staff.aDueText = #\"\" \\partcombine { ")
 				(d-DirectivePut-voice-display tag (_ "Part Combine "))
 				(d-DirectivePut-voice-override tag (logior DENEMO_OVERRIDE_GRAPHIC DENEMO_OVERRIDE_LILYPOND))
+				
+				(if name (d-DirectivePut-voice-allow tag (d-GetIdForName name)))
+				
 				(d-MoveToVoiceDown)
 				(d-DirectivePut-voice-prefix tag " } %{next voice is combined with previous part %} ")
 				(d-DirectivePut-voice-display tag (_ "Part Combine "))
-				(d-DirectivePut-voice-override tag (logior DENEMO_OVERRIDE_GRAPHIC DENEMO_OVERRIDE_LILYPOND))))
+				(d-DirectivePut-voice-override tag (logior DENEMO_OVERRIDE_GRAPHIC DENEMO_OVERRIDE_LILYPOND))
+				
+				(if name (d-DirectivePut-voice-allow tag (d-GetIdForName name)))))
 		(d-SetSaved #f))
 
 	(d-PushPosition)
@@ -28,7 +33,7 @@
 				(install-combine)))
 		(if (d-MoveToVoiceUp)
 				(if (d-MoveToVoiceUp)
-					(d-WarningDialog (_ "Only two voices can be part-combined"))
+					(d-WarningDialog (_ "Can only part-combine two voices"))
 					(install-combine))
 				(d-WarningDialog (_ "Must be on a staff with two voices"))))
-	(d-PopPosition))
+	(d-PopPosition))
\ No newline at end of file
